@@ -188,7 +188,7 @@ CKCmFontInst::CKCmFontInst(QWidget *parent, const QVariantList&)
 
     KIconLoader::global()->addAppDir(KFI_NAME);
 
-    KAboutData *about = new KAboutData(QStringLiteral("fontinst"), QString(), i18n("KDE Font Manager"), QString(),
+    KAboutData *about = new KAboutData(QStringLiteral("fontinst"), i18n("KDE Font Manager"), QStringLiteral("1.0"), QString(),
                                        KAboutLicense::GPL, i18n("(C) Craig Drummond, 2000 - 2009"));
     about->addAuthor(i18n("Craig Drummond"), i18n("Developer and maintainer"), QStringLiteral("craig@kde.org"));
     setAboutData(about);
